==> sqlrelay-0.27.tgz: include/private/sqlrcursor.h <==
// Copyright (c) 1999-2001  David Muse
// See the file COPYING for more information.

	private:
		void	clearConnectionPorts();
		void	clearResultSet();
		void	clearCacheDest();
		void	clearCacheSource();
		void	clearError();
		void	clearColumns();
		void	clearRowBuffers();
		void	clearVariables();
		void	initVariables();
		void	deleteVariables();

		void	initQueryBuffer();
		int	sendQueryInternal(char *query);
		void	validateBindsInternal(char *query);
		void	sendInputBinds();
		void	sendOutputBinds();
		void	sendGetColumnInfo();
		void	stringVar(bindvar *var, char *variable, char *value);
		void	longVar(bindvar *var, char *variable, long value);
		void	doubleVar(bindvar *var, char *variable, 
						double value,
						short precision,
						short scale);
		void	initVar(bindvar *var, char *variable);
		void	performSubstitution(strstream *buffer, int which);
		int	runQuery(char *query);
		void	abortResultSet();
		int	processResultSet(int rowtoget);

		int	getString(char *string, int size);
		int	getShort(short *integer);
		int	getLong(long *integer);

		int	noError();
		int	getCursorId();
		int	getSuspended();
		int	parseColumnInfo();
		int	parseOutputBinds();
		int	parseData();
		void	setError(char *err);
		void	getErrorFromServer();
		void	handleError();

		int	skipAndFetch(int rowtoget);
		void	fetchRows();
		int	skipRows(int rowtoget);

		void	startCaching();
		void	cacheNoError();
		void	cacheColumnInfo();
		void	cacheOutputBinds(int count);
		void	cacheData();
		void	finishCaching();
		void	suspendCaching();
 
		int	fetchRowIntoBuffer(int row);

		void	createColumnArrays();
		void	createFieldArray();

		int		resumed;
		int		cached;

		// query
		char		*querybuffer;
		char		*queryptr;
		char		*fullpath;
		int		reexecute;

		// substitution variables
		bindvar		subvars[MAXVAR];
		int		subcount;

		// bind variables
		bindvar		inbindvars[MAXVAR];
		int		inbindcount;
		bindvar		outbindvars[MAXVAR];
		int		outbindcount;
		int		validatebinds;

		// result set
		long		rsbuffersize;
		short		sendcolumninfo;
		short		sentcolumninfo;

		short		suspendresultsetsent;
		long		firstrowindex;
		long		colcount;
		long		rowcount;
		short		knowsactualrows;
		long		actualrows;
		short		knowsaffectedrows;
		long		affectedrows;
		short		endofresultset;

		column		*firstcol;
		column		*currentcol;

		row		*firstrow;
		row		*currentrow;

		column		**columnarray;
		char		**columnnamearray;
		char		***fieldarray;
		long		**fieldlengtharray;

		int		returnnulls;

		char		*id;

		// result set caching
		int		cacheon;
		int		cachettl;
		char		*cachedestname;
		char		*cachedestindname;
		ofstream	*cachedestfd;
		ofstream	*cachedestindfd;
		int		cachesourcefd;
		int		cachesourceindfd;

		// error
		char		*error;

		// copy references flag
		int		copyrefs;

		// parent connection
		sqlrconnection	*sqlrc;

		// next/previous pointers
		sqlrcursor	*next;
		sqlrcursor	*prev;

		// cursor id
		short		cursorid;

	public:
		void		copyReferences();

	friend class sqlrconnection;

==> sqlrelay-0.30_2.tgz: include/private/sqlrcursor.h <==
// Copyright (c) 1999-2001  David Muse
// See the file COPYING for more information.

	private:
		void	clearConnectionPorts();
		void	clearResultSet();
		void	clearCacheDest();
		void	clearCacheSource();
		void	clearError();
		void	clearColumns();
		void	clearRowBuffers();
		void	clearVariables();
		void	initVariables();
		void	deleteVariables();

		void	initQueryBuffer();
		int	sendQueryInternal(char *query);
		void	validateBindsInternal(char *query);
		void	sendInputBinds();
		void	sendOutputBinds();
		void	sendGetColumnInfo();
		void	stringVar(bindvar *var, char *variable, char *value);
		void	longVar(bindvar *var, char *variable, long value);
		void	doubleVar(bindvar *var, char *variable, 
						double value,
						unsigned short precision,
						unsigned short scale);
		void	initVar(bindvar *var, char *variable);
		void	performSubstitution(strstream *buffer, int which);
		int	runQuery(char *query);
		void	abortResultSet();
		int	processResultSet(int rowtoget);

		int	getString(char *string, int size);
		int	getShort(unsigned short *integer);
		int	getLong(unsigned long *integer);

		int	noError();
		int	getCursorId();
		int	getSuspended();
		int	parseColumnInfo();
		int	parseOutputBinds();
		int	parseData();
		void	setError(char *err);
		void	getErrorFromServer();
		void	handleError();

		int	skipAndFetch(int rowtoget);
		void	fetchRows();
		int	skipRows(int rowtoget);

		void	startCaching();
		void	cacheNoError();
		void	cacheColumnInfo();
		void	cacheOutputBinds(int count);
		void	cacheData();
		void	finishCaching();
		void	suspendCaching();
 
		int	fetchRowIntoBuffer(int row);

		void	createColumnArrays();
		void	createFieldArray();

		int		resumed;
		int		cached;

		// query
		char		*querybuffer;
		char		*queryptr;
		char		*fullpath;
		int		reexecute;

		// substitution variables
		bindvar		subvars[MAXVAR];
		int		subcount;

		// bind variables
		bindvar		inbindvars[MAXVAR];
		int		inbindcount;
		bindvar		outbindvars[MAXVAR];
		int		outbindcount;
		int		validatebinds;

		// result set
		long		rsbuffersize;
		unsigned short	sendcolumninfo;
		unsigned short	sentcolumninfo;

		unsigned short	suspendresultsetsent;
		unsigned long	firstrowindex;
		unsigned long	colcount;
		long		rowcount;
		unsigned short	knowsactualrows;
		unsigned long	actualrows;
		unsigned short	knowsaffectedrows;
		unsigned long	affectedrows;
		unsigned short	endofresultset;

		column		*firstcol;
		column		*currentcol;

		row		*firstrow;
		row		*currentrow;

		column		**columnarray;
		char		**columnnamearray;
		char		***fieldarray;
		unsigned long	**fieldlengtharray;

		int		nonstandardtypescount;
		char		**nonstandardtypes;

		int		returnnulls;

		// result set caching
		int		cacheon;
		int		cachettl;
		char		*cachedestname;
		char		*cachedestindname;
		ofstream	*cachedestfd;
		ofstream	*cachedestindfd;
		int		cachesourcefd;
		int		cachesourceindfd;

		// error
		char		*error;

		// copy references flag
		int		copyrefs;

		// parent connection
		sqlrconnection	*sqlrc;

		// next/previous pointers
		sqlrcursor	*next;
		sqlrcursor	*prev;

		// cursor id
		unsigned short	cursorid;

	public:
		void		copyReferences();

	friend class sqlrconnection;
